MemorySource class

In-memory byte buffer source.

Inheritance

Constructors

MemorySource(Uint8List bytes, {String? basePath})

Properties

basePath String?
Base directory or context path for resolving relative sample paths.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getBytes([int? offset, int? length]) Future<Uint8List>
Fetches byte buffer of the main file or a byte slice.
override
getByteStream([int? offset, int? length, int chunkSize = 16384]) Stream<Uint8List>
Returns a stream of byte chunks for a given offset and length.
inherited
getSubFileBytes(String relativePath) Future<Uint8List>
Fetches sub-file bytes (e.g. for SFZ sample files or ZIP archives).
override
getSubFileByteStream(String relativePath, {int chunkSize = 16384}) Stream<Uint8List>
Returns a stream of byte chunks for a subfile.
inherited
hasSubFile(String relativePath) Future<bool>
Checks if a relative sub-file exists.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readAsString([String? relativePath]) Future<String>
Reads a text representation of the file (or subfile).
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited