soundfont_kit library
Classes
- AssetSource
- Flutter Asset source.
- FileSource
- Disk file path source.
- FilterParameterInfo
- Metadata description of a single adjustable filter parameter.
- Instrument
- Represents an Instrument containing one or more synthesis zones.
- MemorySource
- In-memory byte buffer source.
- ModulatorInfo
- SF2 Modulator specification data.
- Preset
- Represents a SoundFont Preset (Patch).
- SampleInfo
- Metadata for a sample stored or referenced by a SoundFont.
- SampleStreamer
- Low-latency audio loader and streamer that connects SoundFont samples to SoLoud's memory audio sources and buffer streams.
- SoundFontFile
- Unified main interface for reading and querying SoundFont files (SF2, SF3, and SFZ).
- SoundFontGlobalFilters
- Controller managing SoLoud global output audio filters.
- SoundFontPlayer
-
Comprehensive audio player for SoundFontFile instruments, presets, and samples
powered by
flutter_soloud. - SoundFontPlayerOptions
- Configuration options for SoundFontPlayer.
- SoundFontSource
- Abstract data source for SoundFont files.
- SoundFontVoice
-
Represents one or more active
SoundHandleinstances triggered for a note. - StereoJoiner
- Helper to identify and join stereo 16-bit PCM sample pairs.
- UrlSource
- Remote HTTP URL source.
- VoiceCalculator
- SoundFont voice synthesis and parameter calculation utilities.
- ZipSource
- Zip Archive source (e.g., zipped SFZ + audio files).
- Zone
- Represents a region or zone within an instrument or preset.
Enums
- LoopMode
- Loop mode for sample playback.
- SampleCompression
- Compression or encoding type of sample data.
- SoundFontFilterType
- Available global audio filter types for SoundFont playback.
- SoundFontFormat
- Supported SoundFont file formats.